@@ -14,6 +14,20 @@ sub sql_detect_table {
   return ( sql => "select * from $tablename limit 1" );
 }
 
+########################################################################
+
+sub sql_create_column_type {
+  my($self, $table, $column, $columns) = @_;
+  my $type = $column->{type};
+  if ( $type eq 'sequential' ) {
+    return 'int auto_increment primary key';
+  } elsif ( $type eq 'binary' ) {
+    return 'blob';
+  } else {
+    $self->SUPER::sql_create_column_type( $table, $column, $columns );
+  }
+}
+
 sub sql_create_column_text_long_type {
   'blob'
 }
@@ -80,25 +94,6 @@ sub do_insert_with_sequence {
 
 ########################################################################
 
-sub sql_create_columns {
-  my($self, $table, $column , $columns) = @_;
-  my $name = $column->{name};
-  my $type = $column->{type};
-  if ( $type eq 'sequential' ) {
-    return '  ' . $name . 
-	    ' ' x ( ( length($name) > 31 ) ? ' ' : ( 32 - length($name) ) ) .
-	    'int auto_increment primary key';
-  } elsif ( $type eq 'binary' ) {
-    return '  ' . $name . 
-	    ' ' x ( ( length($name) > 31 ) ? ' ' : ( 32 - length($name) ) ) .
-	    'blob';
-  } else {
-    $self->SUPER::sql_create_columns( $table, $column , $columns );
-  }
-}
-
-########################################################################
-
 sub catch_query_exception {
   my $self = shift;
   my $error = shift;
